summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvasitem_imp.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
commit9ba04742771370f59740e32e11c5f3a1e6a1b70a (patch)
treec81c34dae2b3b1ea73801bf18a960265dc4207f7 /kjsembed/qtbindings/qcanvasitem_imp.h
parent1a96c45b22d01378202d9dc7ed9c47acd30f966e (diff)
downloadtdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.tar.gz
tdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.zip
Initial TQt conversion
Diffstat (limited to 'kjsembed/qtbindings/qcanvasitem_imp.h')
-rw-r--r--kjsembed/qtbindings/qcanvasitem_imp.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kjsembed/qtbindings/qcanvasitem_imp.h b/kjsembed/qtbindings/qcanvasitem_imp.h
index d0823afe..577bb7b1 100644
--- a/kjsembed/qtbindings/qcanvasitem_imp.h
+++ b/kjsembed/qtbindings/qcanvasitem_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TQCanvasItem;
+class TTQCanvasItem;
/**
* Namespace containing the KJSEmbed library.
@@ -17,11 +17,11 @@ class TQCanvasItem;
namespace KJSEmbed {
/**
* Wrapper class for TQCanvasItem methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QCanvasItemImp : public JSProxyImp
+class TQCanvasItemImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -75,8 +75,8 @@ public:
Method_Last = -1
};
- QCanvasItemImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QCanvasItemImp();
+ TQCanvasItemImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQCanvasItemImp();
/**
* Adds the static bindings for this class to the specified Object. The
@@ -90,13 +90,13 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQCanvasItem *toQCanvasItem( KJS::Object &object );
+ static TTQCanvasItem *toTQCanvasItem( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QCanvasItem_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasItem_1( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -158,7 +158,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQCanvasItem *instance; // Temp
+ TTQCanvasItem *instance; // Temp
int id;
bool cons;
};
@@ -17,11 +17,11 @@ class TQCanvasItem;
namespace KJSEmbed {
/**
- * Wrapper class for TQCanvasItem methods.
+ * Wrapper class for TTQCanvasItem methods.
*
* @author Richard Moore, rich@kde.org